<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "Infoga priser f&ouml;r &aring;r"; break;
case "Prezzi della":  				$messaggio = "Priser f&ouml;r"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "soprannominata":  			$messaggio = "vid namn"; break;
case "Dal":  					$messaggio = "Fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "infoga dom nya priserna"; break;
case "modifica i prezzi già inseriti":  	$messaggio = "&auml;ndra redan infogade priser"; break;
case "Costi aggiuntivi":  			$messaggio = "Extrakostnader"; break;
case "Nome del nuovo costo aggiuntivo":		$messaggio = "Nytt extrakostnadsnamn"; break;
case "da applicare":  				$messaggio = "att till&auml;mpa"; break;
case "sempre":  				$messaggio = "alltid"; break;
case "su richiesta":  				$messaggio = "vid f&ouml;rfr&aring;gan"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "fr&aring;ga med hur mycket det m&aring;ste multipliceras"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "se denna extrakostnad som en extras&auml;ng"; break;
case "numero di settimane":  			$messaggio = "antal veckor"; break;
case "numero di giorni":  			$messaggio = "antal dagar"; break;
case "tutte":  					$messaggio = "alla"; break;
case "tutti":  					$messaggio = "alla"; break;
case "tutte meno una":  			$messaggio = "alla minus en"; break;
case "tutti meno uno":  			$messaggio = "alla minus en"; break;
case "chiedere":  				$messaggio = "fr&aring;ga"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "se denna veckoliga kostnad som en extras&auml;ng"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "se denna dagliga kostnad som en extras&auml;ng"; break;
case "della tariffa arrotondato a":  		$messaggio = "f&ouml;r priset avrundat till"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "se procentandelskostnaden som en extras&auml;ng"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Forts&auml;tt med att l&auml;gga till ny extrakostnad"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "arrotondata a":  				$messaggio = "avrundad till"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Infoga eller &auml;ndra depositionen"; break;
case "Vedi i prezzi già inseriti":  		$messaggio = "Visa redan infogade priser"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case "Si deve inserire la percentuale":  	$messaggio = "Du m&aring;ste ange procentandelen"; break;
case "La caparra è stata modificata":  		$messaggio = "Depositionen har &auml;ndrats"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Du m&aring;ste v&auml;lja hur enkelkostnaden ska till&auml;mpas"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "Du m&aring;ste ange namnet p&aring; extrakostnaden"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "Den enkla extrakostnaden"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "finns redan, g&aring; till sidan med perioder och priser f&ouml;r att ta bort den"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Den enkla extrakostnaden f&aring;r inte till&auml;mpas automatiskt f&ouml;r att fr&aring;ga med hur mycket det m&aring;ste multipliceras med."; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "Du m&aring;ste v&auml;lja hur den veckoliga kostnaden ska till&auml;mpas"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "Du m&aring;ste v&auml;lja hur den dagliga kostnaden ska till&auml;mpas"; break;
case "e il numero di settimane":  		$messaggio = "och antalet veckor"; break;
case "e il numero di giorni":  			$messaggio = "och antalet dagar"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "F&ouml;r att fr&aring;ga efter antalet veckor eller med hur mycket det m&aring;ste mltipliceras med f&aring;r den veckoliga extrakostnaden inte till&auml;mpas automatiskt"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "F&ouml;r att fr&aring;ga efter antalet dagar eller med hur mycket det m&aring;ste multipliceras med f&aring;r den dagliga extrakostnaden inte till&auml;pas automatiskt"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "Den veckoliga extrakostnaden"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "Den dagliga extrakostnaden"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "Du m&aring;ste v&auml;lja hur procentandelskostnaden ska till&auml;mpas"; break;
case "e il valore dell'arrotondamento":		$messaggio = "och v&auml;rdet att avrunda till"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "F&ouml;r att fr&aring;ga hur mycket det m&aring;ste ultipliceras med f&aring;r den procentuella extrakostnaden inte till&auml;mpas automatiskt"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "Den procentuella extrakostnaden"; break;
case "è stato inserito":  			$messaggio = "har lagts till"; break;
case "Nessun dato è stato inserito":  		$messaggio = "Inga data har lagts till"; break;
case "Il soprannome della":  			$messaggio = "Namnet p&aring;"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "finns redan, anv&auml;nd knappen \"&auml;ndra redan tillagda priser\" f&ouml;r att &auml;ndra det, eller l&auml;gg inte till det f&ouml;r att l&auml;gga itll priser i de nya perioderna"; break;
case "Il soprannome":  				$messaggio = "Namnet"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "finns redan, du m&aring;ste v&auml;lja ett annat"; break;
case "Le date del periodo numero":  		$messaggio = "Datumen f&ouml;r period nummer"; break;
case "sono sbagliate":  			$messaggio = "&auml;r felaktiga"; break;
case "Il periodo":  				$messaggio = "Perioden"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "&ouml;verlappar med en annan period"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "Ett pris i period nummer"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "finns redan, anv&auml;nd kanppen \"&auml;ndra redan tillagda priser\" f&ouml;r att &auml;ndra det"; break;
case "è stato cambiato":  			$messaggio = "har &auml;ndrats"; break;
case "Il prezzo del periodo":  			$messaggio = "Priset p&aring; period"; break;
case "è stato inserito":  			$messaggio = "har lagts till"; break;
case "Il prezzo del periodo numero":  		$messaggio = "Priset f&ouml;r period nummer"; break;
case "è sbagliato":  				$messaggio = "&auml;r felaktigt"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "Priset f&ouml;r enkelkostnad &auml;r felaktigt"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "Priset f&ouml;r vecklig kostnad &auml;r felaktigt"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "Priset f&ouml;r daglig kostnad &auml;r felaktigt"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "Priset f&ouml;r procentuell kostnad &auml;r felaktigt"; break;
case "Inserzione per settimane":  		$messaggio = "Infogning p&aring; veckolig basis"; break;
case "Settimane dal":  				$messaggio = "Veckor fr&aring;n"; break;
case "Dom/Lun":  				$messaggio = "s&ouml;n/m&aring;n"; break;
case "Lun/Mar":  				$messaggio = "m&aring;n/tis"; break;
case "Mar/Mer":  				$messaggio = "tis/ons"; break;
case "Mer/Gio":  				$messaggio = "ons/tor"; break;
case "Gio/Ven":  				$messaggio = "tor/fre"; break;
case "Ven/Sab":  				$messaggio = "fre/l&ouml;r"; break;
case "Sab/Dom":  				$messaggio = "l&ouml;r/s&ouml;n"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "L&auml;gg till eller &auml;ndra priserna"; break;
case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "Il formato dei soldi è sbagliato":  	$messaggio = "Pengaformatet &auml;r felaktigt"; break;
case "I prezzi per le settimane dal":  		$messaggio = "Priserna f&ouml;r veckor fr&aring;n"; break;
case "della <b>tariffa":  			$messaggio = "till <b>pris"; break;
case "sono stati inseriti":  			$messaggio = "har infogats"; break;
case "si":  					$messaggio = "ja"; break;
case "no":  					$messaggio = "nej"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "automatiskt till&auml;mpade f&ouml;r priser"; break;
case "nessuna":  				$messaggio = "ingen"; break;
case "scegliere":  				$messaggio = "v&auml;lj"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "visa p&aring; bokningstill&auml;ggningssidan"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "V&auml;lj priserna f&ouml;r vilka den <b>enkla</b> extrakostnaden automatiskt ska till&auml;mpas "; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "V&auml;lj priserna f&ouml;r vilka den <b>veckoliga</b> extrakostnaden automatiskt ska till&auml;mpas"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "V&auml;lj priserna f&ouml;r vicka den <b>dagliga</b> extrakostnaden automatiskt ska till&auml;mpas"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "V&auml;lj priserna f&ouml;r vilka den <b>procentuella</b> extrakostnaden automatiskt ska till&auml;mpas"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Tipo di costo aggiuntivo":  		$messaggio = "Extrakostnadstyp"; break;
case "unico":  					$messaggio = "enkel"; break;
case "settimanale":  				$messaggio = "veckolig"; break;
case "giornaliero":  				$messaggio = "daglig"; break;
case "il prezzo totale":  			$messaggio = "totalt pris"; break;
case "la caparra":  				$messaggio = "depositionen"; break;
case "totale meno caparra":  			$messaggio = "totalt minus deposition"; break;
case "minimo":  				$messaggio = "minimal"; break;
case "massimo":  				$messaggio = "maximal"; break;
case "esattamente":  				$messaggio = "exakt"; break;
case "settimane":  				$messaggio = "veckor"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "Se possibile":  				$messaggio = "Om m&ouml;jligt"; break;
case "Sempre":  				$messaggio = "Alltid"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Associera med specifika bokningsveckor"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Associera med specifika bokningsdagar"; break;
case "Tutte":  					$messaggio = "Alla"; break;
case "Tutti":  					$messaggio = "Alla"; break;
case "Tutte meno":  				$messaggio = "Alla minus"; break;
case "Tutti meno":  				$messaggio = "Alla minus"; break;
case "la prima":  				$messaggio = "den f&ouml;rsta"; break;
case "il primo":  				$messaggio = "den f&ouml;rsta"; break;
case "l'ultima":  				$messaggio = "den sista"; break;
case "l'ultimo":  				$messaggio = "den sista"; break;
case "Chiedere":  				$messaggio = "Fr&aring;ga"; break;
case "settimane sì":  				$messaggio = "veckor ja"; break;
case "giorni sì":  				$messaggio = "dagar ja"; break;
case "settimane no":  				$messaggio = "veckor nej"; break;
case "giorni no":  				$messaggio = "dagar nej"; break;
case "e":  					$messaggio = "och"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Valda veckodagar"; break;
case "Lunedì":  				$messaggio = "m&aring;ndag"; break;
case "Martedì":  				$messaggio = "tisdag"; break;
case "Mercoledì":  				$messaggio = "onsdag"; break;
case "Giovedì":  				$messaggio = "torsdag"; break;
case "Venerdì":  				$messaggio = "fredag"; break;
case "Sabato":  				$messaggio = "l&ouml;rdag"; break;
case "Domenica":  				$messaggio = "s&ouml;ndag"; break;
case "Moltiplicare il costo per":  		$messaggio = "Multiplicera kostnaden med"; break;
case "Uno":  					$messaggio = "Ett"; break;
case "Chiedere":  				$messaggio = "Fr&aring;ga"; break;
case "Numero di persone":  			$messaggio = "Antal personer"; break;
case "Numero di persone totale":  		$messaggio = "Totalt antal personer"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "exklusive dom fr&aring;n kostnader med extras&auml;ngar"; break;
case "Periodi in cui è permesso inserire il costo":	$messaggio = "Perioder under vilka det inte &auml;r till&aring;tet att infoga kostnaden"; break;
case "In tutti":  				$messaggio = "Alla"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Endast valda perioder"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "Elimina un periodo":  			$messaggio = "Ta bort period"; break;
case "Aggiungi un periodo":  			$messaggio = "L&auml;gg till period"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "om alla bokningsveckor &auml;r i de valda perioderna"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "om alla bokningsdagar &auml;r i de valda perioderna"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "om endast en vecka i bokningen &auml;r i de valda perioderna"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "om endast en dag i bokningen &auml;r i de valda perioderna"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "till&auml;mpa endast kostnaden p&aring; till&aring;tna bokningsveckor"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "till&auml;mpa endast kostnaden p&aring; till&aring;tna bokningsdagar"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":	$messaggio = "Kostnadskarakteristika att beh&aring;lla n&auml;r en bokning &auml;ndras"; break;
case "Valore percentuale":  			$messaggio = "Procentandelsv&auml;rde"; break;
case "e settimane associate":  			$messaggio = "och tillh&ouml;rande veckor"; break;
case "e giorni associati":  			$messaggio = "och tillh&ouml;rande dagar"; break;
case "Assegnazione settimane":  		$messaggio = "Veckouppl&aring;telse"; break;
case "Assegnazione giorni":  			$messaggio = "Dagsuppl&aring;telse"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Tal med vilket det multipliceras"; break;
case "Periodi permessi":  			$messaggio = "Till&aring;tna perioder"; break;
case "Associazione alle tariffe":  		$messaggio = "Samband med priser"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Visa p&aring; bokningstill&auml;ggningssidan"; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nej"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Se denna extrakostnad som en extras&auml;ng"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Begr&auml;nsa det samtidiga antalet som an has under samma period"; break;
case "Valore del costo":  			$messaggio = "Kostnadsv&auml;rde"; break;
case "fisso di":  				$messaggio = "fast f&ouml;r"; break;
case "percentuale su":  			$messaggio = "procentuellt p&aring;"; break;
case "la tariffa":  				$messaggio = "priset"; break;
case "indietro":  				$messaggio = "bak&aring;t"; break;
case "avanti":  				$messaggio = "fram&aring;t"; break;
case "del":  					$messaggio = "f&ouml;r"; break;
case "arrotondato a":  				$messaggio = "avrundat till"; break;
case "Errore nei valori inseriti":  		$messaggio = "Fel i tillagda v&auml;rden"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Till&auml;mpa automatiskt med valda priser"; break;
case "Tariffe":  				$messaggio = "Priser"; break;
case "Il costo aggiuntivo":  			$messaggio = "Extrakostnaden"; break;
case "OK":  					$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "Veckor att applicera kostnaden p&aring;"; break;
case "I giorni a cui applicare il costo":	$messaggio = "Dagar att applicera kostnaden p&aring;"; break;
case "uno":  					$messaggio = "en"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "SI":  					$messaggio = "JA"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Priser som &auml;r inkompatibla med kostnaden"; break;
case "Tariffe incompatibili":  			$messaggio = "Inkompatibla priser"; break;
case "dalla":  					$messaggio = "fr&aring;n"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "Priserna f&ouml;r vald pristaxa har importerats"; break;
case "importa":  				$messaggio = "importera"; break;
case "se selezionato mantenere anche":  	$messaggio = "om vald, beh&aring;ll ocks&aring;"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "N&auml;r det &auml;r m&ouml;jligt, till&auml;mpa automatiskt om"; break;
case "meno di":  				$messaggio = "mindre &auml;n"; break;
case "più di":  				$messaggio = "mer &auml;n"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "dagar &aring;terst&aring;r fr&aring;n startdatumet f&ouml;r bokningen n&auml;r den l&auml;ggs till"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "N&auml;r m&ouml;jligt till&auml;mpa automatiskt om"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "eller fler bokningar infogas samtidigt"; break;
case "Modifica il costo":  			$messaggio = "&Auml;ndra kostnaden"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "L&auml;gg till en ny extrakostnad vid namn"; break;
case "importando le caratteristiche da":	$messaggio = "importerar inst&auml;llningar fr&aring;n"; break;
case "Sempre in periodi permessi":  		$messaggio = "Alltid i till&aring;tna perioder"; break;
case "Prezzo dell'intera settimana":  		$messaggio = "Pris f&ouml;r en hel vecka"; break;
case "Prezzi dei giorni":  			$messaggio = "Pris f&ouml;r dagar"; break;
case "tra":  					$messaggio = "mellan"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Inventorief&ouml;rem&aring;l att ta bort n&auml;r kostnaden l&auml;ggs till"; break;
case "Nessuno":  				$messaggio = "Inga"; break;
case "Beni selezionati":  			$messaggio = "Valda f&ouml;rem&aring;l"; break;
case "Aggiungi un bene":  			$messaggio = "L&auml;gg till ett f&ouml;rem&aring;l"; break;
case "Elimina un bene":  			$messaggio = "Ta bort ett f&ouml;rem&aring;l"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Ta bort f&ouml;rem&aring;l f&ouml;r f&ouml;rr&aring;dsrums inventarium"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Inventarief&ouml;rem&aring;l att ta bort"; break;
case "è":  					$messaggio = "is"; break;
case "il":  					$messaggio = "the"; break;
case "sono":  					$messaggio = "are"; break;
case "Sulla":  					$messaggio = "On"; break;
case "p":  					$messaggio = "p"; break;
case "Se":  					$messaggio = "If"; break;
case "Se si inseriscono":  			$messaggio = "If"; break;
case "a":  					$messaggio = "to"; break;
case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
case "Inserzione per giorni":			$messaggio = "Insertion on daily basis"; break;
case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
case "i prezzi della":  			$messaggio = "the prices to"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
case "Il tipo di applicazione della":  		$messaggio = "The enforcement type of"; break;
case "per persona":  				$messaggio = "per person"; break;
case "per settimana":  				$messaggio = "per week"; break;
case "per giorno":  				$messaggio = "per day"; break;
case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
case "della tariffa":  				$messaggio = "of the rate"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Insert or modify taxes"; break;
case "Le commissioni sono state modificate":  	$messaggio = "Commissions have been modified"; break;
case "Le commissioni sono errate":  		$messaggio = "Commissions are wrong"; break;
case "Le tasse sono state modificate":  	$messaggio = "Taxes have been modified"; break;
case "Le tasse sono errate":  			$messaggio = "Taxes are wrong"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "All rate prices are considered as already including taxes"; break;
case "Inserisci o modifica le commissioni normali":  	$messaggio = "Insert or modify the normal commissions"; break;
case "Inserisci o modifica le commissioni in questo periodo":  	$messaggio = "Insert or modify commissions in this period"; break;
case "al giorno":  				$messaggio = "per day"; break;
case "alla settimana":  			$messaggio = "per week"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "the cost value is considered as already including taxes"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "the rate price for the first"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for the first"; break;
case "della":  					$messaggio = "of the"; break;
case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
case "della tar.":  				$messaggio = "of rate"; break;
case "di t.+s.":  				$messaggio = "of r.+d."; break;
case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
case "Nome della":  				$messaggio = "Name of"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "prezzo per settimana":  			$messaggio = "price per week"; break;
case "prezzo per giorno":  			$messaggio = "price per day"; break;
case "prezzo per persona per settimana":  	$messaggio = "price per person per week"; break;
case "prezzo per persona per giorno":  		$messaggio = "price per person per day"; break;
case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
case "Numero massimo":  			$messaggio = "Maximum number"; break;
case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
case "meno":  					$messaggio = "minus"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "the cost will be multiplied by zero if the sum is negative"; break;
case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Costi combinati":  			$messaggio = "Combined costs"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Fast insertion of a new extra cost for"; break;
case "permanenza minima":  			$messaggio = "minimum stay"; break;
case "numero di neonati":  			$messaggio = "number of infants"; break;
case "letto aggiuntivo":  			$messaggio = "extra bed"; break;
case "offerta speciale":  			$messaggio = "special offer"; break;
case "inserisci":  				$messaggio = "insert"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
case "Valore dello sconto":  			$messaggio = "Discount value"; break;
case "del prezzo totale":  			$messaggio = "of total price"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation length is"; break;
case "o più giorni":  				$messaggio = "days or more"; break;
case "Importa ora":  				$messaggio = "Import now"; break;
case "Importa sempre":  			$messaggio = "Always import"; break;
case "cancella":  				$messaggio = "delete"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
case "al prezzo per persona":  			$messaggio = "to per person price"; break;
case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
case "tutte le tariffe":  			$messaggio = "all rates"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
case "modifica":  				$messaggio = "modify"; break;
case "In modo predefinito importa":  		$messaggio = "By default import"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
case "escludi":  				$messaggio = "exclude"; break;
case "includi solo":  				$messaggio = "include only"; break;
case "questi tipi":  				$messaggio = "these types"; break;
case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
case "tariffe con":  				$messaggio = "rates with"; break;
case "per persona nullo":  			$messaggio = "per person zero"; break;
case "fisso nullo":  				$messaggio = "fixed zero"; break;
case "da per persona":  			$messaggio = "from per person"; break;
case "più fisso":  				$messaggio = "from fixed"; break;
case "dal fisso":  				$messaggio = "plus fixed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>